@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,7 +34,6 @@
 #include <chrono>
 #include <cstdlib>
 #include <cstring>
-#include <new>
 #include <stdexcept>
 #include <stdlib.h>
 
@@ -55,9 +54,19 @@ namespace fs = std::experimental::filesystem;
 #include <unistd.h>
 #endif
 
+// global for device memory padding see d_vector.hpp
+size_t g_DVEC_PAD = 4096;
+
+void d_vector_set_pad_length(size_t pad)
+{
+    g_DVEC_PAD = pad;
+}
+
 hipblas_rng_t hipblas_rng(69069);
 hipblas_rng_t hipblas_seed(hipblas_rng);
 
+int64_t c_i32_overflow = int64_t(std::numeric_limits<int32_t>::max()) + 1; // 2147483648
+
 template <>
 char type2char<float>()
 {
@@ -71,12 +80,12 @@ char type2char<double>()
 }
 
 //  template<>
-//  char type2char<hipblasComplex>(){
+//  char type2char<std::complex<float>>(){
 //      return 'c';
 //  }
 
 //  template<>
-//  char type2char<hipblasDoubleComplex>(){
+//  char type2char<std::complex<double>>(){
 //      return 'z';
 //  }
 
@@ -93,13 +102,13 @@ int type2int<double>(double val)
 }
 
 template <>
-int type2int<hipblasComplex>(hipblasComplex val)
+int type2int<std::complex<float>>(std::complex<float> val)
 {
     return (int)val.real();
 }
 
 template <>
-int type2int<hipblasDoubleComplex>(hipblasDoubleComplex val)
+int type2int<std::complex<double>>(std::complex<double> val)
 {
     return (int)val.real();
 }
@@ -198,27 +207,29 @@ hipblasLocalHandle::hipblasLocalHandle(const Arguments& arg)
         status = hipblasSetAtomicsMode(m_handle, hipblasAtomicsMode_t(arg.atomics_mode));
     if(status == HIPBLAS_STATUS_SUCCESS)
     {
-        /*
         // If the test specifies user allocated workspace, allocate and use it
         if(arg.user_allocated_workspace)
         {
             if((hipMalloc)(&m_memory, arg.user_allocated_workspace) != hipSuccess)
                 throw std::bad_alloc();
-            status = rocblas_set_workspace(m_handle, m_memory, arg.user_allocated_workspace);
+            status = hipblasSetWorkspace(m_handle, m_memory, arg.user_allocated_workspace);
+            if(status != HIPBLAS_STATUS_SUCCESS)
+                throw std::runtime_error(hipblasStatusToString(status));
         }
-    */
     }
     else
     {
         throw std::runtime_error(hipblasStatusToString(status));
     }
+
+    // memory guard control, with multi-threading should not change values across threads
+    d_vector_set_pad_length(arg.pad);
 }
 
 hipblasLocalHandle::~hipblasLocalHandle()
 {
     if(m_memory)
     {
-        // m_memory never used currently
         auto hipStatus = hipFree(m_memory);
         if(hipStatus != hipSuccess)
         {
@@ -448,18 +459,14 @@ hipblasClientProcessor getArch()
     {
         return hipblasClientProcessor::gfx90a;
     }
-    else if(deviceString.find("gfx940") != std::string::npos)
-    {
-        return hipblasClientProcessor::gfx940;
-    }
-    else if(deviceString.find("gfx941") != std::string::npos)
-    {
-        return hipblasClientProcessor::gfx941;
-    }
     else if(deviceString.find("gfx942") != std::string::npos)
     {
         return hipblasClientProcessor::gfx942;
     }
+    else if(deviceString.find("gfx950") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx950;
+    }
     else if(deviceString.find("gfx1010") != std::string::npos)
     {
         return hipblasClientProcessor::gfx1010;
@@ -488,6 +495,22 @@ hipblasClientProcessor getArch()
     {
         return hipblasClientProcessor::gfx1102;
     }
+    else if(deviceString.find("gfx1150") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1150;
+    }
+    else if(deviceString.find("gfx1151") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1151;
+    }
+    else if(deviceString.find("gfx1200") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1200;
+    }
+    else if(deviceString.find("gfx1201") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1201;
+    }
     return static_cast<hipblasClientProcessor>(0);
 }
 
