@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -48,6 +48,7 @@ inline void testname_hpmv_strided_batched(const Arguments& arg, std::string& nam
 template <typename T>
 void testing_hpmv_strided_batched_bad_arg(const Arguments& arg)
 {
+    using Ts     = hipblas_internal_type<T>;
     bool FORTRAN = arg.api == hipblas_client_api::FORTRAN;
 
     auto hipblasHpmvStridedBatchedFn
@@ -74,11 +75,14 @@ void testing_hpmv_strided_batched_bad_arg(const Arguments& arg)
 
         device_vector<T> d_alpha(1), d_beta(1), d_one(1), d_zero(1);
 
-        const T  h_alpha(1), h_beta(2), h_one(1), h_zero(0);
-        const T* alpha = &h_alpha;
-        const T* beta  = &h_beta;
-        const T* one   = &h_one;
-        const T* zero  = &h_zero;
+        Ts h_alpha{1}, h_beta{2}, h_one{1}, h_zero{0};
+        if constexpr(is_complex<T>)
+            h_one = {1, 0};
+
+        const Ts* alpha = &h_alpha;
+        const Ts* beta  = &h_beta;
+        const Ts* one   = &h_one;
+        const Ts* zero  = &h_zero;
 
         if(pointer_mode == HIPBLAS_POINTER_MODE_DEVICE)
         {
@@ -328,6 +332,7 @@ void testing_hpmv_strided_batched_bad_arg(const Arguments& arg)
 template <typename T>
 void testing_hpmv_strided_batched(const Arguments& arg)
 {
+    using Ts     = hipblas_internal_type<T>;
     bool FORTRAN = arg.api == hipblas_client_api::FORTRAN;
     auto hipblasHpmvStridedBatchedFn
         = FORTRAN ? hipblasHpmvStridedBatched<T, true> : hipblasHpmvStridedBatched<T, false>;
@@ -431,13 +436,13 @@ void testing_hpmv_strided_batched(const Arguments& arg)
                    (handle,
                     uplo,
                     N,
-                    (T*)&h_alpha,
+                    reinterpret_cast<Ts*>(&h_alpha),
                     dAp,
                     stride_A,
                     dx,
                     incx,
                     stride_x,
-                    (T*)&h_beta,
+                    reinterpret_cast<Ts*>(&h_beta),
                     dy,
                     incy,
                     stride_y,
