@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -51,6 +51,7 @@ inline void testname_syr2k_strided_batched(const Arguments& arg, std::string& na
 template <typename T>
 void testing_syr2k_strided_batched_bad_arg(const Arguments& arg)
 {
+    using Ts                             = hipblas_internal_type<T>;
     auto hipblasSyrk2StridedBatchedFn    = arg.api == FORTRAN ? hipblasSyr2kStridedBatched<T, true>
                                                               : hipblasSyr2kStridedBatched<T, false>;
     auto hipblasSyrk2StridedBatchedFn_64 = arg.api == FORTRAN_64
@@ -81,12 +82,14 @@ void testing_syr2k_strided_batched_bad_arg(const Arguments& arg)
     device_strided_batch_matrix<T> dC(N, N, ldc, stride_C, batch_count);
 
     device_vector<T> d_alpha(1), d_zero(1), d_beta(1), d_one(1);
-    const T          h_alpha(1), h_zero(0), h_beta(2), h_one(1);
+    Ts               h_alpha{1}, h_zero{0}, h_beta{2}, h_one{1};
+    if constexpr(is_complex<T>)
+        h_one = {1, 0};
 
-    const T* alpha = &h_alpha;
-    const T* beta  = &h_beta;
-    const T* one   = &h_one;
-    const T* zero  = &h_zero;
+    const Ts* alpha = &h_alpha;
+    const Ts* beta  = &h_beta;
+    const Ts* one   = &h_one;
+    const Ts* zero  = &h_zero;
 
     for(auto pointer_mode : {HIPBLAS_POINTER_MODE_HOST, HIPBLAS_POINTER_MODE_DEVICE})
     {
@@ -390,6 +393,7 @@ void testing_syr2k_strided_batched_bad_arg(const Arguments& arg)
 template <typename T>
 void testing_syr2k_strided_batched(const Arguments& arg)
 {
+    using Ts                             = hipblas_internal_type<T>;
     auto hipblasSyrk2StridedBatchedFn    = arg.api == FORTRAN ? hipblasSyr2kStridedBatched<T, true>
                                                               : hipblasSyr2kStridedBatched<T, false>;
     auto hipblasSyrk2StridedBatchedFn_64 = arg.api == FORTRAN_64
@@ -507,14 +511,14 @@ void testing_syr2k_strided_batched(const Arguments& arg)
                     transA,
                     N,
                     K,
-                    &h_alpha,
+                    reinterpret_cast<Ts*>(&h_alpha),
                     dA,
                     lda,
                     stride_A,
                     dB,
                     ldb,
                     stride_B,
-                    &h_beta,
+                    reinterpret_cast<Ts*>(&h_beta),
                     dC,
                     ldc,
                     stride_C,
