@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -81,13 +81,13 @@ inline void ref_asum(int64_t n, const double* x, int64_t incx, double* result)
 }
 
 template <>
-inline void ref_asum(int64_t n, const hipblasComplex* x, int64_t incx, float* result)
+inline void ref_asum(int64_t n, const std::complex<float>* x, int64_t incx, float* result)
 {
     *result = cblas_scasum(n, x, incx);
 }
 
 template <>
-inline void ref_asum(int64_t n, const hipblasDoubleComplex* x, int64_t incx, double* result)
+inline void ref_asum(int64_t n, const std::complex<double>* x, int64_t incx, double* result)
 {
     *result = cblas_dzasum(n, x, incx);
 }
@@ -564,6 +564,18 @@ void ref_gemm(hipblasOperation_t transA,
               To*                C,
               int64_t            ldc);
 
+// dgmm
+template <typename T>
+void ref_dgmm(hipblasSideMode_t side,
+              int64_t           M,
+              int64_t           N,
+              const T*          dA,
+              int64_t           lda,
+              const T*          dx,
+              int64_t           incx,
+              T*                dC,
+              int64_t           ldc);
+
 // hemm
 template <typename T>
 void ref_hemm(hipblasSideMode_t side,
@@ -709,17 +721,17 @@ inline void ref_trsm<double>(hipblasSideMode_t  side,
 }
 
 template <>
-inline void ref_trsm<hipblasComplex>(hipblasSideMode_t     side,
-                                     hipblasFillMode_t     uplo,
-                                     hipblasOperation_t    transA,
-                                     hipblasDiagType_t     diag,
-                                     int64_t               m,
-                                     int64_t               n,
-                                     hipblasComplex        alpha,
-                                     const hipblasComplex* A,
-                                     int64_t               lda,
-                                     hipblasComplex*       B,
-                                     int64_t               ldb)
+inline void ref_trsm<std::complex<float>>(hipblasSideMode_t          side,
+                                          hipblasFillMode_t          uplo,
+                                          hipblasOperation_t         transA,
+                                          hipblasDiagType_t          diag,
+                                          int64_t                    m,
+                                          int64_t                    n,
+                                          std::complex<float>        alpha,
+                                          const std::complex<float>* A,
+                                          int64_t                    lda,
+                                          std::complex<float>*       B,
+                                          int64_t                    ldb)
 {
     cblas_ctrsm(CblasColMajor,
                 (CBLAS_SIDE)side,
@@ -736,16 +748,16 @@ inline void ref_trsm<hipblasComplex>(hipblasSideMode_t     side,
 }
 
 template <>
-inline void ref_trsm<hipblasDoubleComplex>(hipblasSideMode_t           side,
+inline void ref_trsm<std::complex<double>>(hipblasSideMode_t           side,
                                            hipblasFillMode_t           uplo,
                                            hipblasOperation_t          transA,
                                            hipblasDiagType_t           diag,
                                            int64_t                     m,
                                            int64_t                     n,
-                                           hipblasDoubleComplex        alpha,
-                                           const hipblasDoubleComplex* A,
+                                           std::complex<double>        alpha,
+                                           const std::complex<double>* A,
                                            int64_t                     lda,
-                                           hipblasDoubleComplex*       B,
+                                           std::complex<double>*       B,
                                            int64_t                     ldb)
 {
     cblas_ztrsm(CblasColMajor,
@@ -790,22 +802,32 @@ void ref_trmm(hipblasSideMode_t  side,
 
 // potrf
 template <typename T>
-int ref_potrf(char uplo, int m, T* A, int lda);
+int64_t ref_potrf(char uplo, int64_t m, T* A, int64_t lda);
 
 template <typename T>
-int ref_getrf(int m, int n, T* A, int lda, int* ipiv);
+int64_t ref_getrf(int64_t m, int64_t n, T* A, int64_t lda, int64_t* ipiv);
 
 template <typename T>
-int ref_getrs(char trans, int n, int nrhs, T* A, int lda, int* ipiv, T* B, int ldb);
+int64_t ref_getrs(
+    char trans, int64_t n, int64_t nrhs, T* A, int64_t lda, int64_t* ipiv, T* B, int64_t ldb);
 
 template <typename T>
-int ref_getri(int n, T* A, int lda, int* ipiv, T* work, int lwork);
+int64_t ref_getri(int64_t n, T* A, int64_t lda, int64_t* ipiv, T* work, int64_t lwork);
 
 template <typename T>
-int ref_geqrf(int m, int n, T* A, int lda, T* tau, T* work, int lwork);
+int64_t ref_geqrf(int64_t m, int64_t n, T* A, int64_t lda, T* tau, T* work, int64_t lwork);
 
 template <typename T>
-int ref_gels(char trans, int m, int n, int nrhs, T* A, int lda, T* B, int ldb, T* work, int lwork);
+int64_t ref_gels(char    trans,
+                 int64_t m,
+                 int64_t n,
+                 int64_t nrhs,
+                 T*      A,
+                 int64_t lda,
+                 T*      B,
+                 int64_t ldb,
+                 T*      work,
+                 int64_t lwork);
 
 #endif
 
