@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -226,14 +226,15 @@ int main()
 
     for(int i = 0; i < size_c; i++)
     {
-        float relative_error = (hc_gold[i] - hc[i]) / hc_gold[i];
-        relative_error       = relative_error > 0 ? relative_error : -relative_error;
+        float relative_error
+            = hc_gold[i] == 0 ? (hc_gold[i] - hc[i]) : (hc_gold[i] - hc[i]) / hc_gold[i];
+        relative_error = relative_error > 0 ? relative_error : -relative_error;
         max_relative_error
             = relative_error < max_relative_error ? max_relative_error : relative_error;
     }
-    float eps       = std::numeric_limits<float>::epsilon();
+    float half_eps  = 0.000488; // approx 2^-11, rounding machine epsilon for ieee754 half precision
     float tolerance = 10;
-    if(max_relative_error != max_relative_error || max_relative_error > eps * tolerance)
+    if(max_relative_error != max_relative_error || max_relative_error > half_eps * tolerance)
     {
         std::cout << "FAIL: max_relative_error = " << max_relative_error << std::endl;
     }
